@@ -707,7 +707,7 @@ def csv_rows_from_content(content: Union[str, bytes], *,
     Examples:
     
     >>> pipe(csv_rows_from_content('c1,c2,c3\n1,2,3'), list)
-    [OrderedDict([('c1', '1'), ('c2', '2'), ('c3', '3')])]
+    [{'c1': '1', 'c2': '2', 'c3': '3'}]
 
     If header is False, then rows will be returned as lists.
     
@@ -717,7 +717,7 @@ def csv_rows_from_content(content: Union[str, bytes], *,
     >>> pipe(csv_rows_from_content(
     ...   '1,2,3', header=False, columns=['c1', 'c2', 'c3']
     ... ), list)
-    [OrderedDict([('c1', '1'), ('c2', '2'), ('c3', '3')])]
+    [{'c1': '1', 'c2': '2', 'c3': '3'}]
 
     If header is False and header row exists, the header row will be
     interpreted as a regular row.
@@ -825,10 +825,19 @@ def csv_rows_to_fp(wfp, rows: Iterable[Union[dict, Sequence[str]]], *,
     ... )
     >>> assert wfp.getvalue() == '1,2\r\n3,4\r\n'
 
+    >>> wfp = io.StringIO()
+    >>> pipe([], csv_rows_to_fp(wfp))
+    >>> assert wfp.getvalue() == ''
     '''
     
     row_iter = iter(rows)
-    first_row = next(row_iter)
+
+    try:
+        first_row = next(row_iter)
+    except StopIteration:
+        log.error('No rows in row iterator... stopping, no write made.')
+        return
+
     # If rows are passed as iterable of sequences, each row must be an
     # in-memory sequence like a list, tuple, or pvector (i.e. not an
     # iter or generator), otherwise, this will have the
@@ -1159,6 +1168,9 @@ def vmapif(func, seq):
 
 @curry
 def groupdicts(regex, iterable, keep_match=False, **kw):
+    '''Given a regex (str or re.Pattern), and iterable of strings, 
+    produce single dictionary of all groupdicts of matches
+    '''
     regex = regex if isinstance(regex, re.Pattern) else re.compile(regex, **kw)
     return pipe(
         iterable,
@@ -1172,6 +1184,9 @@ def groupdicts(regex, iterable, keep_match=False, **kw):
 @curry
 def groupdicts_from_regexes(regexes: Sequence[re.Pattern],
                             iterable: Iterable[str], **kw):
+    '''Given a sequence of regexes and an iterable of strings,
+    produce a list of merged groupdicts for those regexes
+    '''
     return pipe(
         iterable,
         juxt(*[compose(list, groupdicts(r, **kw)) for r in regexes]),
